@@ -1,6 +1,6 @@
 /*
 **  GNU Pth - The GNU Portable Threads
-**  Copyright (c) 1999-2003 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 1999-2004 Ralf S. Engelschall <rse@engelschall.com>
 **
 **  This file is part of GNU Pth, a non-preemptive thread scheduling
 **  library which can be found at http://www.gnu.org/software/pth/.
@@ -196,7 +196,7 @@ pth_event_t pth_event(unsigned long spec, ...)
         /* custom function event */
         ev->ev_type = PTH_EVENT_FUNC;
         ev->ev_goal = (int)(spec & (PTH_UNTIL_OCCURRED));
-        ev->ev_args.FUNC.func  = (int (*)(void *))va_arg(ap, void *);
+        ev->ev_args.FUNC.func  = va_arg(ap, int (*)(void *));
         ev->ev_args.FUNC.arg   = va_arg(ap, void *);
         ev->ev_args.FUNC.tv    = va_arg(ap, pth_time_t);
     }
@@ -266,10 +266,10 @@ int pth_event_extract(pth_event_t ev, ...)
     }
     else if (ev->ev_type & PTH_EVENT_FUNC) {
         /* custom function event */
-        void **func    = va_arg(ap, void **);
-        void **arg     = va_arg(ap, void **);
-        pth_time_t *tv = va_arg(ap, pth_time_t *);
-        *func = (int (**)(void *))ev->ev_args.FUNC.func;
+        int (**func)(void *) = va_arg(ap, int (**)(void *));
+        void **arg           = va_arg(ap, void **);
+        pth_time_t *tv       = va_arg(ap, pth_time_t *);
+        *func = ev->ev_args.FUNC.func;
         *arg  = ev->ev_args.FUNC.arg;
         *tv   = ev->ev_args.FUNC.tv;
     }
