@@ -1,6 +1,6 @@
 /*
 **  GNU Pth - The GNU Portable Threads
-**  Copyright (c) 1999-2003 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 1999-2004 Ralf S. Engelschall <rse@engelschall.com>
 **
 **  This file is part of GNU Pth, a non-preemptive thread scheduling
 **  library which can be found at http://www.gnu.org/software/pth/.
@@ -364,7 +364,7 @@ fmtstr(
     int padlen, strln;
     int cnt = 0;
 
-    if (value == 0)
+    if (value == NULL)
         value = "<NULL>";
     for (strln = 0; value[strln] != '\0'; strln++)
         ;
@@ -476,7 +476,7 @@ fmtint(
 }
 
 static LDOUBLE
-abs_val(LDOUBLE value)
+math_abs(LDOUBLE value)
 {
     LDOUBLE result = value;
     if (value < 0)
@@ -485,18 +485,18 @@ abs_val(LDOUBLE value)
 }
 
 static LDOUBLE
-pow10(int exp)
+math_pow10(int exponent)
 {
     LDOUBLE result = 1;
-    while (exp) {
+    while (exponent > 0) {
         result *= 10;
-        exp--;
+        exponent--;
     }
     return result;
 }
 
 static long
-round(LDOUBLE value)
+math_round(LDOUBLE value)
 {
     long intpart;
     intpart = (long) value;
@@ -530,7 +530,7 @@ fmtfp(
 
     if (max < 0)
         max = 6;
-    ufvalue = abs_val(fvalue);
+    ufvalue = math_abs(fvalue);
     if (fvalue < 0)
         signvalue = '-';
     else if (flags & DP_F_PLUS)
@@ -547,11 +547,11 @@ fmtfp(
 
     /* we "cheat" by converting the fractional part to integer by
        multiplying by a factor of 10 */
-    fracpart = round((pow10(max)) * (ufvalue - intpart));
+    fracpart = math_round((math_pow10(max)) * (ufvalue - intpart));
 
-    if (fracpart >= pow10(max)) {
+    if (fracpart >= math_pow10(max)) {
         intpart++;
-        fracpart -= pow10(max);
+        fracpart -= math_pow10(max);
     }
 
     /* convert integer part */
